==> simpler-6.x-1.2.tar.gz: simpler/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.6 2010/02/28 02:37:38 danprobo Exp $
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
 </head>

<body<?php print phptemplate_body_class($left, $right); ?>>
<div id="page">

<?php if ($content_header): ?>
      		<div id="content-header"><?php print $content_header; ?></div>
      	<?php endif; ?>

	<div id="header-region">
		<?php if (isset($secondary_links)) : ?><?php print theme('links', $secondary_links, array('class' => 'links', 'id' => 'subnavlist')); ?><?php endif; ?>
	</div>


	<div id="header">
		<div class="logo">
			<div class="column">
				<?php if ($logo): ?>
					<div id="logo"><a href="<?php print $base_path; ?>" title="<?php print t('Home'); ?>"><img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" /></a></div>
				<?php endif; ?>
				<?php if ($site_name) : ?><h1 class="logo-name"><a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>"><?php print $site_name; ?></a></h1><?php endif; ?>
				<?php if ($site_slogan) : ?><div class='logo-text'><?php print $site_slogan; ?></div><?php endif; ?>
			</div>
		</div>

		<?php if ($search_box): ?>
      		<div id="search-box"><?php print $search_box; ?></div>
      	<?php endif; ?>

		<?php if (isset($primary_links)) : ?>
			<?php print theme('links', $primary_links, array('class' => 'links', 'id' => 'navlist')); ?>
		<?php endif; ?>

	</div>


	<div id="container">
		<div class="column">

		<?php if ($left): ?>
			<div id="sidebar-left" class="sidebar">
				<?php print $left ?>
			</div>
		<?php endif; ?>

		<div id="main">
			<?php if ($mission) : ?><div id="mission"><?php print $mission; ?></div><?php endif; ?>
			<?php if ($content_top) : ?><div id="content-top" class="node"><?php print $content_top; ?></div>
			<?php endif; ?>
			<?php if (!$is_front) print $breadcrumb; ?>
			<?php if ($show_messages) { print $messages; }; ?>
			<?php if ($tabs) : ?><div class="tabs"><?php print $tabs; ?></div><?php endif; ?>
			<?php if ($title) : ?><h1 class="title"><?php print $title; ?></h1><?php endif; ?>
			<?php print $help; ?>
			<?php if ($content) : ?><div id="content-bottom"><?php print $content; ?></div><?php endif; ?>
			<?php print $feed_icons; ?>
		</div>

		<?php if ($right): ?>
			<div id="sidebar-right" class="sidebar">
				<?php print $right; ?>
			</div>
		<?php endif; ?>
		<div style="clear: both;"> </div>

     		</div>

	</div>
</div>

<div id="bottom-header"></div>
		
    <?php if ($bottom_first || $bottom_middle || $bottom_last || $footer || $footer_message): ?>
    <div id="bottoms">
      <div id="bottom-wrapper" class="<?php print $bottoms; ?> clearfix">
        <?php if ($bottom_first): ?>
        <div id="bottom-first" class="column">
          <?php print $bottom_first; ?>
        </div><!-- /bottom-first -->
        <?php endif; ?>
        <?php if ($bottom_middle): ?>
        <div id="bottom-middle" class="column">
          <?php print $bottom_middle; ?>
        </div><!-- /bottom-middle -->
        <?php endif; ?>
        <?php if ($bottom_last): ?>
        <div id="bottom-last" class="column">
          <?php print $bottom_last; ?>
        </div><!-- /bottom-last -->
        <?php endif; ?>
	 <?php if ($footer || $footer_message): ?>
    <div id="footer" class="clearfix">
      <div id="footer-wrapper">
        <?php if ($footer_message): ?>
        <div id="footer-message">
          <?php print $footer_message; ?>
        </div>
        <?php endif; ?>
        <?php if ($footer) : ?>
          <div id="footer-region">
            <?php print $footer; ?>
          </div>
        <?php endif; ?>
	<div id="notice"><p>Theme provided by <a href="http://www.xpsdev.com">Danang Probo Sayekti</a>.</p></div>
      </div><!-- /footer-wrapper -->
    </div><!-- /footer -->
    <?php endif; ?>
      </div><!-- /bottom-wrapper -->
    </div><!-- /bottoms -->
    <?php endif; ?>

		
<?php print $closure; ?>
</body>
</html>

==> simpler-6.x-1.3.tar.gz: simpler/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.10 2010/03/17 16:49:36 danprobo Exp $
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <meta http-equiv="Content-Style-Type" content="text/css" />
  <?php print $styles; ?>
  <?php print $scripts; ?>
 </head>

<body<?php print phptemplate_body_class($left, $right); ?>>
<div id="page">

<?php if ($content_header): ?>
      		<div id="content-header"><?php print $content_header; ?></div>
      	<?php endif; ?>

	<div id="header-region">
		<?php if (isset($secondary_links)) : ?><?php print theme('links', $secondary_links, array('class' => 'links', 'id' => 'subnavlist')); ?><?php endif; ?>
	</div>


	<div id="header">
		<div class="logo">
			<div class="column">
				<?php if ($logo): ?>
					<div id="logo"><a href="<?php print $base_path; ?>" title="<?php print t('Home'); ?>"><img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" /></a></div>
				<?php endif; ?>
				<?php if ($site_name) : ?><h1 class="logo-name"><a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>"><?php print $site_name; ?></a></h1><?php endif; ?>
				<?php if ($site_slogan) : ?><div class='logo-text'><?php print $site_slogan; ?></div><?php endif; ?>
			</div>
		</div>

		<?php if ($search_box): ?>
      		<div id="search-box"><?php print $search_box; ?></div>
      	<?php endif; ?>

		<?php if (isset($primary_links)) : ?>
			<?php print theme('links', $primary_links, array('class' => 'links', 'id' => 'navlist')); ?>
		<?php endif; ?>

	</div>


	<div id="container">
		<div class="column">

		<?php if ($left): ?>
			<div id="sidebar-left" class="sidebar">
				<?php print $left ?>
			</div>
		<?php endif; ?>

		<div id="main">
			<?php if ($mission) : ?><div id="mission"><?php print $mission; ?></div><?php endif; ?>
			<?php if ($content_top) : ?><div id="content-top" class="node"><?php print $content_top; ?></div>
			<?php endif; ?>
			<?php if (!$is_front) print $breadcrumb; ?>
			<?php if ($show_messages) { print $messages; }; ?>
			<?php if ($tabs) : ?><div class="tabs"><?php print $tabs; ?></div><?php endif; ?>
			<?php if ($title) : ?><h1 class="title"><?php print $title; ?></h1><?php endif; ?>
			<?php print $help; ?>
			<?php if ($content) : ?><div id="content-bottom"><?php print $content; ?></div><?php endif; ?>
			<?php print $feed_icons; ?>
		</div>

		<?php if ($right): ?>
			<div id="sidebar-right" class="sidebar">
				<?php print $right; ?>
			</div>
		<?php endif; ?>
		<div style="clear: both;"> </div>

     		</div>

	</div>
</div>

<div id="bottom-header"></div>
		
    <?php if ($bottom_first || $bottom_middle || $bottom_last || $footer || $footer_message): ?>
    <div id="bottoms">
      <div id="bottom-wrapper">
        <?php if ($bottom_first): ?>
        <div id="bottom-first" class="column">
          <?php print $bottom_first; ?>
        </div><!-- /bottom-first -->
        <?php endif; ?>
        <?php if ($bottom_middle): ?>
        <div id="bottom-middle" class="column">
          <?php print $bottom_middle; ?>
        </div><!-- /bottom-middle -->
        <?php endif; ?>
        <?php if ($bottom_last): ?>
        <div id="bottom-last" class="column">
          <?php print $bottom_last; ?>
        </div><!-- /bottom-last -->
        <?php endif; ?>
	 <?php if ($footer || $footer_message): ?>
    <div id="footer">
      <div id="footer-wrapper">
        <?php if ($footer_message): ?>
        <div id="footer-message">
          <?php print $footer_message; ?>
        </div>
        <?php endif; ?>
        <?php if ($footer) : ?>
          <div id="footer-region">
            <?php print $footer; ?>
          </div>
        <?php endif; ?>
	<div id="notice"><p>Theme provided by <a href="http://www.xpsdev.com">Danang Probo Sayekti</a>.</p></div>
      </div><!-- /footer-wrapper -->
    </div><!-- /footer -->
    <?php endif; ?>
      </div><!-- /bottom-wrapper -->
    </div><!-- /bottoms -->
    <?php endif; ?>

		
<?php print $closure; ?>
</body>
</html>
